@@ -186,7 +186,7 @@ class Package(ExtensionBase):
 
     # pylint: disable=too-many-arguments
     def download_file(self, project, package, filename, destdir, meta=False,
-                      overwrite=False, rev=None):
+                      overwrite=False, rev=None, expand=False):
         """
         Download a file to directory
 
@@ -197,11 +197,16 @@ class Package(ExtensionBase):
         :param meta: switch to meta files
         :param overwrite: switch to overwrite existing downloaded file
         :param rev: Download file from this specific package revision
+        :param expand: If ``True`` and the package is a link, download the file from the linked
+                       package
         :return: absolute path to file or ``None``
         :raises OSError: if something goes wrong
 
         .. versionadded:: 0.1.1
             Parameter rev
+
+        .. versionchanged:: 0.3.3
+            Added the parameter ``expand``
         """
         abspath_filename = os.path.abspath(os.path.join(destdir, filename))
         if os.path.isfile(destdir):
@@ -215,7 +220,7 @@ class Package(ExtensionBase):
         if not os.path.exists(destdir):
             os.makedirs(destdir)
 
-        response = self.get_file(project, package, filename, meta=meta, rev=rev)
+        response = self.get_file(project, package, filename, meta=meta, rev=rev, expand=expand)
 
         with open(abspath_filename, "wb") as handle:
             for chunk in response.iter_content(1024):
@@ -343,7 +348,7 @@ class Package(ExtensionBase):
 
         return response.text
 
-    def checkout(self, project, package, destdir, rev=None, meta=False):
+    def checkout(self, project, package, destdir, rev=None, meta=False, expand=False):
         """
         Checkout all files and directories of package
 
@@ -355,9 +360,14 @@ class Package(ExtensionBase):
         :param destdir: target local directory
         :param rev: Package revision to check out
         :param meta: Checkout meta files instead
+        :param expand: If ``True`` and the package is a link, download the file from the linked
+                       package
         :return: nothing
 
         .. versionadded:: 0.1.1
+
+        .. versionchanged:: 0.3.3
+            Added the parameter ``expand``
         """
         if not os.path.exists(destdir):
             if not os.path.isdir(destdir):
@@ -368,7 +378,7 @@ class Package(ExtensionBase):
         oscdir = DataDir(osc=self.osc, path=destdir, project=project,
                          package=package)
 
-        dirlist = self.get_files(project, package, rev=rev, meta=meta)
+        dirlist = self.get_files(project, package, rev=rev, meta=meta, expand=expand)
         for entry in dirlist.findall("entry"):
             self.download_file(
                 project=project,
@@ -377,7 +387,8 @@ class Package(ExtensionBase):
                 destdir=destdir,
                 meta=meta,
                 overwrite=True,
-                rev=rev
+                rev=rev,
+                expand=expand
             )
             os.link(
                 os.path.join(destdir, entry.get("name")),
